package com.ruoyi.mall.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.MallGoodsPostFeeMapper;
import com.ruoyi.mall.domain.MallGoodsPostFee;
import com.ruoyi.mall.service.IMallGoodsPostFeeService;

/**
 * 商品邮费Service业务层处理
 * 
 * @author chang
 * @date 2021-11-25
 */
@Service
public class MallGoodsPostFeeServiceImpl implements IMallGoodsPostFeeService 
{
    @Autowired
    private MallGoodsPostFeeMapper mallGoodsPostFeeMapper;

    /**
     * 查询商品邮费
     * 
     * @param id 商品邮费主键
     * @return 商品邮费
     */
    @Override
    public MallGoodsPostFee selectMallGoodsPostFeeById(Long id)
    {
        return mallGoodsPostFeeMapper.selectMallGoodsPostFeeById(id);
    }

    /**
     * 查询商品邮费列表
     * 
     * @param mallGoodsPostFee 商品邮费
     * @return 商品邮费
     */
    @Override
    public List<MallGoodsPostFee> selectMallGoodsPostFeeList(MallGoodsPostFee mallGoodsPostFee)
    {
        return mallGoodsPostFeeMapper.selectMallGoodsPostFeeList(mallGoodsPostFee);
    }

    /**
     * 新增商品邮费
     * 
     * @param mallGoodsPostFee 商品邮费
     * @return 结果
     */
    @Override
    public int insertMallGoodsPostFee(MallGoodsPostFee mallGoodsPostFee)
    {
        return mallGoodsPostFeeMapper.insertMallGoodsPostFee(mallGoodsPostFee);
    }

    /**
     * 修改商品邮费
     * 
     * @param mallGoodsPostFee 商品邮费
     * @return 结果
     */
    @Override
    public int updateMallGoodsPostFee(MallGoodsPostFee mallGoodsPostFee)
    {
        return mallGoodsPostFeeMapper.updateMallGoodsPostFee(mallGoodsPostFee);
    }

    /**
     * 批量删除商品邮费
     * 
     * @param ids 需要删除的商品邮费主键
     * @return 结果
     */
    @Override
    public int deleteMallGoodsPostFeeByIds(Long[] ids)
    {
        return mallGoodsPostFeeMapper.deleteMallGoodsPostFeeByIds(ids);
    }

    /**
     * 删除商品邮费信息
     * 
     * @param id 商品邮费主键
     * @return 结果
     */
    @Override
    public int deleteMallGoodsPostFeeById(Long id)
    {
        return mallGoodsPostFeeMapper.deleteMallGoodsPostFeeById(id);
    }
}
